==> owncloud-app-calendar-1%3A1.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/he.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "יומן",
    "Individual" : "פרטני",
    "Group" : "קבוצה",
    "Resource" : "משאב",
    "Room" : "חדר",
    "Unknown" : "לא ידוע",
    "Required" : "נדרש",
    "Optional" : "אופציונלי",
    "Does not attend" : "לא משתתף",
    "New event" : "אירוע חדש",
    "Attendees" : "משתתפים",
    "Reminders" : "תזכורות",
    "Repeating" : "חוזר",
    "When shared show full event" : "כאשר משותף מציג אירוע מלא",
    "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
    "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
    "Please add a title!" : "יש להוסיף כותרת!",
    "Please select a calendar!" : "יש לבחור לוח שנה!",
    "Global" : "גלובלי",
    "None" : "כלום",
    "Every day" : "כל יום",
    "Every week" : "כל שבוע",
    "Every month" : "כל חודש",
    "Every year" : "כל שנה",
    "never" : "לעולם לא",
    "after" : "לאחר",
    "At time of event" : "בזמן אירוע",
    "5 minutes before" : "5 דקות לפני",
    "10 minutes before" : "10 דקות לפני",
    "15 minutes before" : "15 דקות לפני",
    "30 minutes before" : "30 דקות לפני",
    "1 hour before" : "1 שעה לפני",
    "2 hours before" : "2 שעות לפני",
    "Custom" : "מותאם אישית",
    "Audio" : "קובץ שמע",
    "E Mail" : "דואר אלקטרוני",
    "Pop up" : "חלון קופץ",
    "sec" : "שניות",
    "min" : "דקות",
    "hours" : "שעות",
    "days" : "ימים",
    "week" : "שבוע",
    "before" : "לפני",
    "start" : "התחלה",
    "end" : "סוף",
    "Editing reminders of uknown type not supported." : "עריכת תזכורות של סוגים לא ידועים אינה נתמכת.",
    "Week {number} of {year}" : "שבוע {number} מ- {year}",
    "Successfully imported" : "יובא בהצלחה",
    "Partially imported, 1 failure" : "יובא חלקית, 1 שגיאה",
    "Partially imported, {n} failures" : "יובא חלקית, {n} שגיאות",
    "Audio alarm" : "תזכורת קולית",
    "Pop-up" : "חלון קופץ",
    "E-Mail" : "דואר אלקטרוני",
    "{type} {time} before the event starts" : "{type} {time} לפני תחילת האירוע",
    "{type} {time} before the event ends" : "{type} {time} לפני סיום האירוע",
    "{type} {time} after the event starts" : "{type} {time} אחרי תחילת האירוע",
    "{type} {time} after the event ends" : "{type} {time} אחרי סיום האירוע",
    "{type} at the event's start" : "{type} בתחילת האירוע",
    "{type} at the event's end" : "{type} בסיום האירוע",
    "{type} at {time}" : "{type} בשעה {time}",
    "{calendar} shared by {owner}" : "{calendar} משותף על ידי {owner}",
    "Title of the Event" : "כותרת האירוע",
    "starts" : "מתחיל",
    "ends" : "מסתיים",
    "All day Event" : "אירוע יום מלא",
    "Location" : "מיקום",
    "Delete" : "מחיקה",
    "Cancel" : "ביטול",
    "More ..." : "עוד...",
    "Create" : "יצירה",
    "Update" : "עדכון",
    "Close" : "סגירה",
    "Description" : "תיאור",
    "Export" : "ייצוא",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "בשל באג upstream, היומן לא יכול לספק תמיכה לתכונת asset pipeline.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "יש ליצור קשר עם המנהל שלך לבקש לנטרל את אפשרות תצורה \"asset-pipeline.enabled\".",
    "Day" : "יום",
    "Week" : "שבוע",
    "Month" : "חודש",
    "Today" : "היום",
    "Share Calendar" : "שיתוף לוח שנה",
    "More" : "יותר",
    "Edit" : "עריכה",
    "group" : "קבוצה",
    "New Calendar" : "לוח שנה חדש",
    "Subscriptions" : "מנויים",
    "New Subscription" : "מנוי חדש",
    "Url" : "נתיב אינטרנט",
    "Edit event" : "ערוך אירוע",
    "Delete Event" : "מחיקת אירוע",
    "Save Event" : "שמירת אירוע",
    "Time" : "זמן",
    "Type" : "סוג",
    "Relative" : "יחסי",
    "Absolute" : "מוחלט",
    "Repeat" : "חזרה",
    "times every" : "פעמים כל",
    "Add" : "הוספה",
    "E-Mail address of attendee" : "כתובת דואר אלקטרוני של משתתף",
    "Please add your email address in the personal settings in order to add attendees." : "יש להזין את כתובת הדואר האלקטרוני שלך בהגדרות האישיות בכדי להוסיף מוזמנים.",
    "from" : "מאת",
    "to" : "אל",
    "This event's repeating rule is not supported yet." : "כלל חזרה לאירוע זה עדיין אינו נתמך.",
    "Support for advanced rules will be added with subsequent updates." : "תמיכת כללים מתקדמים תתווסף עם עדכונים מאוחרים יותר.",
    "Reset repeating rule" : "איפוס כלל חזרה",
    "Repeat every ..." : "חזרה כל...",
    "end repeat ..." : "סיום חזרה...",
    "times" : "פעמים",
    "Import Calendars" : "יבוא יומנים",
    "Import canceled" : "יבוא בוטל",
    "Analyzing calendar" : "מנתח יומן",
    "The file contains objects incompatible with the selected calendar" : "הקובץ כולל אוביקטים שאינם נתמכים על ידי היומן הנבחר",
    "New calendar" : "לוח שנה חדש",
    "Import scheduled" : "לוח זמנים ליבוא",
    "Settings" : "הגדרות",
    "Import calendar" : "יבוא יומן",
    "No Calendars selected for import" : "לא נבחרו יומנים ליבוא",
    "Primary CalDAV address" : "כתובת CalDAV ראשית",
    "iOS/OS X CalDAV address" : "כתובת CalDAV עבור iOS/OS X"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-calendar-1%3A1.3.2-3-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/he.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "יומן",
    "Individual" : "פרטני",
    "Group" : "קבוצה",
    "Resource" : "משאב",
    "Room" : "חדר",
    "Unknown" : "לא ידוע",
    "Required" : "נדרש",
    "Optional" : "אופציונלי",
    "Does not attend" : "לא משתתף",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "הנך באזור זמן לא ידוע ({tz}), מעביר חזרה לאזור זמן UTC",
    "Please create a calendar first." : "יש ליצור לוח שנה תחילה.",
    "New event" : "אירוע חדש",
    "Attendees" : "משתתפים",
    "Reminders" : "תזכורות",
    "Repeating" : "חוזר",
    "When shared show full event" : "כאשר משותף מציג אירוע מלא",
    "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
    "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
    "Please add a title!" : "יש להוסיף כותרת!",
    "Please select a calendar!" : "יש לבחור לוח שנה!",
    "Global" : "גלובלי",
    "None" : "כלום",
    "Every day" : "כל יום",
    "Every week" : "כל שבוע",
    "Every month" : "כל חודש",
    "Every year" : "כל שנה",
    "never" : "לעולם לא",
    "after" : "לאחר",
    "At time of event" : "בזמן אירוע",
    "5 minutes before" : "5 דקות לפני",
    "10 minutes before" : "10 דקות לפני",
    "15 minutes before" : "15 דקות לפני",
    "30 minutes before" : "30 דקות לפני",
    "1 hour before" : "1 שעה לפני",
    "2 hours before" : "2 שעות לפני",
    "Custom" : "מותאם אישית",
    "Audio" : "קובץ שמע",
    "E Mail" : "דואר אלקטרוני",
    "Pop up" : "חלון קופץ",
    "sec" : "שניות",
    "min" : "דקות",
    "hours" : "שעות",
    "days" : "ימים",
    "week" : "שבוע",
    "before" : "לפני",
    "start" : "התחלה",
    "end" : "סוף",
    "Editing reminders of unknown type not supported." : "עריכת תזכורות מסוגים לא מוכרים אינה נתמכת.",
    "Week {number} of {year}" : "שבוע {number} מ- {year}",
    "Successfully imported" : "יובא בהצלחה",
    "Partially imported, 1 failure" : "יובא חלקית, 1 שגיאה",
    "Partially imported, {n} failures" : "יובא חלקית, {n} שגיאות",
    "Audio alarm" : "תזכורת קולית",
    "Pop-up" : "חלון קופץ",
    "E-Mail" : "דואר אלקטרוני",
    "{type} {time} before the event starts" : "{type} {time} לפני תחילת האירוע",
    "{type} {time} before the event ends" : "{type} {time} לפני סיום האירוע",
    "{type} {time} after the event starts" : "{type} {time} אחרי תחילת האירוע",
    "{type} {time} after the event ends" : "{type} {time} אחרי סיום האירוע",
    "{type} at the event's start" : "{type} בתחילת האירוע",
    "{type} at the event's end" : "{type} בסיום האירוע",
    "{type} at {time}" : "{type} בשעה {time}",
    "{calendar} shared by {owner}" : "{calendar} משותף על ידי {owner}",
    "Title of the Event" : "כותרת האירוע",
    "starts" : "מתחיל",
    "ends" : "מסתיים",
    "All day Event" : "אירוע יום מלא",
    "Delete" : "מחיקה",
    "Cancel" : "ביטול",
    "More ..." : "עוד...",
    "Create" : "יצירה",
    "Update" : "עדכון",
    "Close" : "סגירה",
    "Location" : "מיקום",
    "Description" : "תיאור",
    "Export" : "ייצוא",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "בשל באג upstream, היומן לא יכול לספק תמיכה לתכונת asset pipeline.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "יש ליצור קשר עם המנהל שלך לבקש לנטרל את אפשרות תצורה \"asset-pipeline.enabled\".",
    "Day" : "יום",
    "Week" : "שבוע",
    "Month" : "חודש",
    "Today" : "היום",
    "Share Calendar" : "שיתוף לוח שנה",
    "More" : "יותר",
    "Edit" : "עריכה",
    "CalDAV" : "CalDAV",
    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
    "can edit" : "ניתן לערוך",
    "group" : "קבוצה",
    "New Calendar" : "לוח שנה חדש",
    "Subscriptions" : "מנויים",
    "New Subscription" : "מנוי חדש",
    "Url" : "נתיב אינטרנט",
    "Edit event" : "ערוך אירוע",
    "Delete Event" : "מחיקת אירוע",
    "Save Event" : "שמירת אירוע",
    "Time" : "זמן",
    "Type" : "סוג",
    "Relative" : "יחסי",
    "Absolute" : "מוחלט",
    "Repeat" : "חזרה",
    "times every" : "פעמים כל",
    "Add" : "הוספה",
    "E-Mail address of attendee" : "כתובת דואר אלקטרוני של משתתף",
    "Please add your email address in the personal settings in order to add attendees." : "יש להזין את כתובת הדואר האלקטרוני שלך בהגדרות האישיות בכדי להוסיף מוזמנים.",
    "from" : "מאת",
    "to" : "אל",
    "This event's repeating rule is not supported yet." : "כלל חזרה לאירוע זה עדיין אינו נתמך.",
    "Support for advanced rules will be added with subsequent updates." : "תמיכת כללים מתקדמים תתווסף עם עדכונים מאוחרים יותר.",
    "Reset repeating rule" : "איפוס כלל חזרה",
    "Repeat every ..." : "חזרה כל...",
    "end repeat ..." : "סיום חזרה...",
    "times" : "פעמים",
    "Import Calendars" : "יבוא יומנים",
    "Import canceled" : "יבוא בוטל",
    "Analyzing calendar" : "מנתח יומן",
    "The file contains objects incompatible with the selected calendar" : "הקובץ כולל אוביקטים שאינם נתמכים על ידי היומן הנבחר",
    "New calendar" : "לוח שנה חדש",
    "Import scheduled" : "לוח זמנים ליבוא",
    "Settings" : "הגדרות",
    "Import calendar" : "יבוא יומן",
    "No Calendars selected for import" : "לא נבחרו יומנים ליבוא",
    "Primary CalDAV address" : "כתובת CalDAV ראשית",
    "iOS/OS X CalDAV address" : "כתובת CalDAV עבור iOS/OS X"
},
"nplurals=2; plural=(n != 1);");
